@@ -396,7 +396,7 @@ def stats_computation(
             "min": round(float(np.min(array)), 5),
             "mean": round(float(np.mean(array)), 5),
             "std": round(float(np.std(array)), 5),
-            "rmse": round(float(np.sqrt(np.mean(array * array)))),
+            "rmse": round(float(np.sqrt(np.mean(array * array))), 5),
             "median": round(float(np.nanmedian(array)), 5),
             "nmad": round(
                 float(
@@ -527,8 +527,8 @@ def get_stats(
 
     # Computing stats for all sets (sets are a partition of all values)
     if sets is not None and sets_labels is not None and sets_names is not None:
-        for set_idx, _ in enumerate(sets):
-            set_item = sets[set_idx] * to_keep_mask * outliers_free_mask
+        for set_idx, set_item in enumerate(sets):
+            set_item = set_item * to_keep_mask * outliers_free_mask
 
             data = dz_values[np.where(set_item == True)]  # noqa: E712
             output_list.append(stats_computation(data, list_threshold))
